@@ -3,9 +3,11 @@ Main interface for kinesisanalytics service type definitions.
 
 Usage::
 
-    from mypy_boto3.kinesisanalytics.type_defs import ApplicationDetailTypeDef
+    ```python
+    from mypy_boto3_kinesisanalytics.type_defs import ApplicationDetailTypeDef
 
     data: ApplicationDetailTypeDef = {...}
+    ```
 """
 from datetime import datetime
 import sys
